==> react-native-animmated-image-resizer-1.0.3-beta.1.tgz: package/android/src/main/java/com/imageresizer/TargetWebp.java <==
package com.imageresizer;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.drawable.Drawable;
import android.util.Log;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.bumptech.glide.integration.webp.decoder.WebpDecoder;
import com.bumptech.glide.integration.webp.decoder.WebpDrawable;
import com.bumptech.glide.request.target.CustomTarget;
import com.bumptech.glide.request.transition.Transition;
import com.n4no.webpencoder.codec.WebpBitmapEncoder;
import com.nbadal.gifencoder.AnimatedGifEncoder;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

public class TargetWebp extends CustomTarget<WebpDrawable>{
    private final String TAG = TargetWebp.class.getCanonicalName();
    private final StaticOptions options;
    public CodecCallback callback;
    public Context context;
    private final ExecutorService executor = Executors.newSingleThreadExecutor(); // Create an Executor

    public TargetWebp(Context context, CodecCallback callback, StaticOptions options) {
        this.context = context;
        this.callback = callback;
        this.options = options;
        Log.d(TAG,"sync webp target inti. ");

    }

    @Override
    public void onLoadCleared(@Nullable Drawable placeholder) {
        Log.d(TAG," webp target : rsc clear. ");

    }

    @Override
    public void onResourceReady(@NonNull WebpDrawable resource, @Nullable Transition<? super WebpDrawable> transition) {
        Log.d(TAG,"onResourceReady. ");

        // 0.
        WebpDecoder decoder;
        try {
            decoder = DecoderProvider.getWebpDecoder(resource);
        } catch (IllegalAccessException | NoSuchFieldException e) {
            Log.d(TAG,"StandardGifDecoder : "+e.getMessage());
            throw new RuntimeException(e);
        }

        // 1
        WebpDecoder finalDecoder = decoder;
        if (finalDecoder == null) {
            Log.d(TAG,"finalDecoder null ");
            throw new IllegalArgumentException("GIF decoder is null");
        }

        // background
        executor.submit(()->{
            Log.d(TAG,"executor. ");

            String path;
            Log.d(TAG,"outFormat "+options.outFormat);
            if(options.outFormat.equalsIgnoreCase("webp")){
                Log.d(TAG,"executor: encodeToWebp ");
                path = encodeToWebp(finalDecoder);
                Log.d(TAG,"executor: encodeToWebp DONE ");

            }else{
                Log.v(TAG,"executor: GIF?? ");

                path = encodeToGif(finalDecoder);
            }
            callback.onComplete(path);
        });
    }




    private String encodeToGif(WebpDecoder finalDecoder) {
        // 1. create File
        File outputFile =  new FileUtility().createOutputFile("gif");

        // 2. Encoder
        AnimatedGifEncoder gifEncoder = new AnimatedGifEncoder();
        gifEncoder.start(outputFile.getAbsolutePath());

        // delay ;
        int count = finalDecoder.getNextDelay();
        if(count < 80) count = 80;
        gifEncoder.setDelay(80);

        // 3. Loop
        for (int i = 0; i < count; i++) {
            Bitmap bitmap = finalDecoder.getNextFrame();
            if (bitmap == null) {
                gifEncoder.finish();
                throw new RuntimeException("Null Bitmap Frame by getNextFrame ");
            }

            Bitmap newBitmap = BitmapUtility.resizeBitmap(bitmap, options);

            gifEncoder.addFrame(newBitmap);
            bitmap.recycle();
            newBitmap.recycle();
            // Move Next frame
            finalDecoder.advance();
        }
        gifEncoder.finish();
        // finall close and inform
        return outputFile.getAbsolutePath();
    }

    private String encodeToWebp(WebpDecoder finalDecoder) {

        Log.d(TAG,"Encoding to webo");
        // 1. create File
        File outputFile =  new FileUtility().createOutputFile("webp");

        // 2. Encoder
        WebpBitmapEncoder encoder;
        try {
            encoder = new WebpBitmapEncoder(outputFile);
        } catch (FileNotFoundException e) {
            Log.d(TAG,"Error created file not found: "+e.getMessage());
            throw new RuntimeException(e);
        }
        encoder.setLoops(0);


        // 3. Loop
        int count = finalDecoder.getFrameCount();
        for (int i = 0; i < count; i++) {
            int delay = finalDecoder.getNextDelay();
            if(delay < 80) delay = 80;

            Bitmap bitmap = finalDecoder.getNextFrame();
            if (bitmap == null) {
                throw new RuntimeException("Null Bitmap Frame by getNextFrame ");
            }
            try {
                Bitmap newBitmap = BitmapUtility.resizeBitmap(bitmap, options);
                encoder.setDuration(delay);
                encoder.writeFrame(newBitmap, options.quality);
                bitmap.recycle();
                newBitmap.recycle();
                if (i == count - 1) encoder.close();
            } catch (IOException e) {

                Log.d(TAG,"e "+e.getMessage());
                throw new RuntimeException(e);
            }

            // Move Next frame
            finalDecoder.advance();
        }

        // finall close and inform
        return outputFile.getAbsolutePath();

    }




}

==> react-native-animmated-image-resizer-1.0.6-beta.1.tgz: package/android/src/main/java/com/imageresizer/TargetWebp.java <==
package com.imageresizer;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.drawable.Drawable;
import android.util.Log;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.bumptech.glide.integration.webp.decoder.WebpDecoder;
import com.bumptech.glide.integration.webp.decoder.WebpDrawable;
import com.bumptech.glide.request.target.CustomTarget;
import com.bumptech.glide.request.transition.Transition;
import com.gifencoder.AnimatedGifEncoder;
import com.n4no.webpencoder.codec.WebpBitmapEncoder;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

public class TargetWebp extends CustomTarget<WebpDrawable>{
    private final String TAG = TargetWebp.class.getCanonicalName();
    private final StaticOptions options;
    public CodecCallback callback;
    public Context context;
    private final ExecutorService executor = Executors.newSingleThreadExecutor(); // Create an Executor

    public TargetWebp(Context context, CodecCallback callback, StaticOptions options) {
        this.context = context;
        this.callback = callback;
        this.options = options;
        Log.d(TAG,"sync webp target inti. ");

    }
    public TargetWebp(StaticOptions options) {
        this.options = options;
        Log.d(TAG,"sync webp target inti. ");
    }

    @Override
    public void onLoadCleared(@Nullable Drawable placeholder) {
        Log.d(TAG," webp target : rsc clear. ");

    }

    @Override
    public void onResourceReady(@NonNull WebpDrawable resource, @Nullable Transition<? super WebpDrawable> transition) {
        Log.d(TAG,"onResourceReady. ");

        // 0.
        WebpDecoder decoder;
        try {
            decoder = DecoderProvider.getWebpDecoder(resource);
        } catch (IllegalAccessException | NoSuchFieldException e) {
            Log.d(TAG,"StandardGifDecoder : "+e.getMessage());
            throw new RuntimeException(e);
        }

        // 1
        WebpDecoder finalDecoder = decoder;
        if (finalDecoder == null) {
            Log.d(TAG,"finalDecoder null ");
            throw new IllegalArgumentException("GIF decoder is null");
        }

        // background
        executor.submit(()->{
            Log.d(TAG,"executor. ");

            String path;
            Log.d(TAG,"outFormat "+options.outFormat);
            if(options.outFormat.equalsIgnoreCase("webp")){
                Log.d(TAG,"executor: encodeToWebp ");
                path = encodeToWebp(finalDecoder);
                Log.d(TAG,"executor: encodeToWebp DONE ");

            }else{
                Log.v(TAG,"executor: GIF?? ");

                path = encodeToGif(finalDecoder);
            }
            callback.onComplete(path);
        });
    }




    public String encodeToGif(WebpDecoder finalDecoder) {
        // 1. create File
        File outputFile =  new FileUtility().createOutputFile("gif");

        // 2. Encoder
        AnimatedGifEncoder gifEncoder = new AnimatedGifEncoder();
        gifEncoder.start(outputFile.getAbsolutePath());

        // delay ;
        int count = finalDecoder.getNextDelay();
        if(count < 80) count = 80;
        gifEncoder.setDelay(80);

        // 3. Loop
        for (int i = 0; i < count; i++) {
            Bitmap bitmap = finalDecoder.getNextFrame();
            if (bitmap == null) {
                gifEncoder.finish();
                throw new RuntimeException("Null Bitmap Frame by getNextFrame ");
            }

            Bitmap newBitmap = BitmapUtility.resizeBitmap(bitmap, options);

            gifEncoder.addFrame(newBitmap);
            bitmap.recycle();
            newBitmap.recycle();
            // Move Next frame
            finalDecoder.advance();
        }
        gifEncoder.finish();
        // finall close and inform
        return outputFile.getAbsolutePath();
    }

    public String encodeToWebp(WebpDecoder finalDecoder) {

        Log.d(TAG,"Encoding to webo");
        // 1. create File
        File outputFile =  new FileUtility().createOutputFile("webp");

        // 2. Encoder
        WebpBitmapEncoder encoder;
        try {
            encoder = new WebpBitmapEncoder(outputFile);
        } catch (FileNotFoundException e) {
            Log.d(TAG,"Error created file not found: "+e.getMessage());
            throw new RuntimeException(e);
        }
        encoder.setLoops(0);


        // 3. Loop
        int count = finalDecoder.getFrameCount();
        for (int i = 0; i < count; i++) {
            int delay = finalDecoder.getNextDelay();
            if(delay < 80) delay = 80;

            Bitmap bitmap = finalDecoder.getNextFrame();
            if (bitmap == null) {
                throw new RuntimeException("Null Bitmap Frame by getNextFrame ");
            }
            try {
                Bitmap newBitmap = BitmapUtility.resizeBitmap(bitmap, options);
                encoder.setDuration(delay);
                encoder.writeFrame(newBitmap, options.quality);
                bitmap.recycle();
                newBitmap.recycle();
                if (i == count - 1) encoder.close();
            } catch (IOException e) {

                Log.d(TAG,"e "+e.getMessage());
                throw new RuntimeException(e);
            }

            // Move Next frame
            finalDecoder.advance();
        }

        // finall close and inform
        return outputFile.getAbsolutePath();

    }




}
